<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/src/bedrock_server_manager/web/static/image/icon/favicon.svg" alt="ICON" width="200" height="200">
</div> 

# Bedrock Server Manager

Bedrock Server Manager is a comprehensive python server designed for installing, managing, and maintaining Minecraft Bedrock Dedicated Servers with ease, compatible with Linux/Windows.

<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/bedrock-server-manager?label=Version&color=green">
<img alt="PyPI Downloads" src="https://static.pepy.tech/personalized-badge/bedrock-server-manager?period=total&units=INTERNATIONAL_SYSTEM&left_color=GRAY&right_color=YELLOW&left_text=PYPI+Installs">
<img alt="Docker Pulls" src="https://img.shields.io/docker/pulls/dmedina559/bedrock-server-manager?label=Docker%20Pulls&color=pink">
<img alt="GitHub License" src="https://img.shields.io/github/license/dmedina559/bedrock-server-manager?label=License&color=orange">

See the [documentation](https://bedrock-server-manager.readthedocs.io/en/latest/) for more information.

Quick links:

- [Changelog](https://bedrock-server-manager.readthedocs.io/en/latest/changelog.html)
- [Installation](https://bedrock-server-manager.readthedocs.io/en/latest/general/introduction.html#prerequisites)
- [Docker Installation](https://bedrock-server-manager.readthedocs.io/en/latest/extras/docker.html)
- [CLI Commands](https://bedrock-server-manager.readthedocs.io/en/latest/cli/commands.html)
- [Web Interface](https://bedrock-server-manager.readthedocs.io/en/latest/web/general.html)
- [Plugins](https://bedrock-server-manager.readthedocs.io/en/latest/plugins/introduction.html)

# Project Images

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/cli_menu.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/main_index.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/cli_manage_server_menu.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/web_install_addons.png" alt="ICON" width="400" height="200">
</div> 

